print("import: 'wheel'")
import wheel

print("import: 'wheel.cli'")
import wheel.cli

print("import: 'wheel.vendored'")
import wheel.vendored

print("import: 'wheel.vendored.packaging'")
import wheel.vendored.packaging

